@@ -35,7 +35,7 @@
 
 package UMLS::Similarity;
 
-$VERSION = '0.03';
+$VERSION = '0.05';
 
 sub new
 {
@@ -108,42 +108,41 @@ __END__
 
 UMLS::Similarity - This is a suite of Perl modules that implements a 
 number of measures of semantic relatedness. These algorithms use the 
-UMLS-Interface module to access teh Unified Medical Language System 
+UMLS-Interface module to access the Unified Medical Language System 
 (UMLS) to generate relatedness scores between concepts.
 
 =head1 SYNOPSIS
 
-    #!/usr/bin/perl
-
-  use UMLS::Interface;
-  use UMLS::Similarity::lch;
-
-  my $umls = UMLS::Interface->new(); 
-  die "Unable to create UMLS::Interface object.\n" if(!$umls);
-  ($errCode, $errString) = $umls->getError();
-  die "$errString\n" if($errCode);
-
-  my $lch = UMLS::Similarity::lch->new($umls);
-  die "Unable to create measure object.\n" if(!$lch);
-   
-  my $path = UMLS::Similarity::path->new($umls);
-  die "Unable to create measure object.\n" if(!$path);
+use UMLS::Interface;
   
-  my $cui1 = "C0005767";
-  my $cui2 = "C0007634";
-	
-  @ts1 = $umls->getTermList($cui1);
-  my $term1 = pop @ts1;
+use UMLS::Similarity::lch;
+use UMLS::Similarity::path;
 
-  @ts2 = $umls->getTermList($cui2);
-  my $term2 = pop @ts2;
+my $umls = UMLS::Interface->new(); 
+die "Unable to create UMLS::Interface object.\n" if(!$umls);
+($errCode, $errString) = $umls->getError();
+die "$errString\n" if($errCode);
 
-  my $lvalue = $lch->getRelatedness($cui1, $cui2);
-  my $pvalue = $path->getRelatedness($cui1, $cui2);
+my $lch = UMLS::Similarity::lch->new($umls);
+die "Unable to create measure object.\n" if(!$lch);
+   
+my $path = UMLS::Similarity::path->new($umls);
+die "Unable to create measure object.\n" if(!$path);
 
-  print "The lch similarity between $cui1 ($term1) and $cui2 ($term2) is $lvalue\n";
-  print "The path similarity between $cui1 ($term1) and $cui2 ($term2) is $pvalue\n";
+my $cui1 = "C0005767";
+my $cui2 = "C0007634";
 
+@ts1 = $umls->getTermList($cui1);
+my $term1 = pop @ts1;
+
+@ts2 = $umls->getTermList($cui2);
+my $term2 = pop @ts2;
+
+my $lvalue = $lch->getRelatedness($cui1, $cui2);
+my $pvalue = $path->getRelatedness($cui1, $cui2);
+
+print "The lch similarity between $cui1 ($term1) and $cui2 ($term2) is $lvalue\n";
+print "The path similarity between $cui1 ($term1) and $cui2 ($term2) is $pvalue\n";
 
 =head1 DESCRIPTION
 
